Class: BooticCli::Commands::Themes
- Inherits:
-
BooticCli::Command
- Object
- Thor
- BooticCli::Command
- BooticCli::Commands::Themes
- Defined in:
- lib/bootic_cli/commands/themes.rb
Defined Under Namespace
Classes: Prompt
Constant Summary
Constants included from BooticCli::Connectivity
BooticCli::Connectivity::DEFAULT_ENV
Instance Method Summary collapse
- #backup(path = nil) ⇒ Object
- #clone(dir = nil) ⇒ Object
- #compare ⇒ Object
- #dev ⇒ Object
- #local_pull(dir) ⇒ Object
- #pair ⇒ Object
- #publish ⇒ Object
- #pull ⇒ Object
- #push ⇒ Object
- #sync ⇒ Object
- #watch ⇒ Object
Methods inherited from BooticCli::Command
Instance Method Details
#backup(path = nil) ⇒ Object
208 209 210 211 212 213 214 |
# File 'lib/bootic_cli/commands/themes.rb', line 208 def backup(path = nil) within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, ['dev'].nil?) path ||= File.join(local_theme.path, "backups", "#{remote_theme.public? ? 'public' : 'dev'}-theme-backup-#{Time.now.to_i}") create_backup_from(remote_theme, local_theme, path) end end |
#clone(dir = nil) ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/bootic_cli/commands/themes.rb', line 20 def clone(dir = nil) logged_in_action do local_theme, remote_theme = theme_selector.setup_theme_pair(['shop'], dir, ['public'], ['dev']) if File.exist?(local_theme.path) prompt.say "Directory already exists! (#{local_theme.path})", :red else prompt.say "Cloning theme files into #{local_theme.path}" # write the pairing info first, so that if the pull below fails partway # through, the directory is still resumable with `bootic themes pull` local_theme.write_subdomain begin workflows.pull(local_theme, remote_theme) rescue BooticCli::Themes::Workflows::RetryableError => e prompt.say e., :red prompt.say "Once your connection is back, run `bootic themes pull` from within #{local_theme.path} to finish cloning.", :magenta exit 1 end end end end |
#compare ⇒ Object
130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/bootic_cli/commands/themes.rb', line 130 def compare within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir) workflows.compare(local_theme, remote_theme) # if we just compared against the dev theme, redo the mumbo-jumbo but with the public one unless remote_theme.public? prompt.pause "Comparing againt public theme now. Press any key to continue.", :cyan local_theme, public_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, true) workflows.compare(local_theme, public_theme) end end end |
#dev ⇒ Object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/bootic_cli/commands/themes.rb', line 47 def dev within_theme do # shop = theme_selector.find_remote_shop(options['shop']) local_theme = theme_selector.select_local_theme(current_dir) shop = theme_selector.find_remote_shop(local_theme.subdomain) remote_theme = theme_selector.select_remote_theme(shop) if ['delete'] if remote_theme.public? return prompt.say("No development theme found!", :red) end unless prompt.yes_or_no?("Are you ABSOLUTELY sure you want to delete your development theme?", false) return prompt.say "No worries, mate." end if remote_theme.delete! prompt.say "No problem! The development theme was removed." else prompt.say "Whoops! Couldn't delete theme dev theme." end else # create unless remote_theme.public? return prompt.say("You already have a development theme set up. If you want to delete it, please pass the --delete flag.", :red) end unless shop.themes.can?(:create_dev_theme) return prompt.say('Dev theme not available!') end unless prompt.yes_or_no?("This will create a development copy of your current public theme. Proceed?", true) return prompt.say "Ok, bye." end result = shop.themes.create_dev_theme if result.has?(:errors) prompt.say "Couldn't create dev theme: #{result.errors.map(&:field).join(', ')}" else prompt.say "Success! You're now working on a development copy of your theme." prompt.say "Any changes you push or sync won't appear on your public website, but on the development version (in /preview/dev)." prompt.say "Once you're ready to merge your changes back, run the `publish` command." end end end end |
#local_pull(dir) ⇒ Object
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/bootic_cli/commands/themes.rb', line 237 def local_pull(dir) within_theme do unless File.directory?(dir) and contains_theme?(dir) prompt.say("Path doesn't exist or doesn't contain theme: #{dir}") exit end dirname = File.dirname(dir) local_theme = theme_selector.select_local_theme(current_dir) parent_theme = theme_selector.select_local_theme(dir) prompt.say "Pulling changes from parent theme at #{dirname}", :green delete_removed = ['delete'].nil? ? false : ['delete'] workflows.pull(local_theme, parent_theme, delete: delete_removed) prompt.say "Synced changes from parent theme at #{dirname} with local one.", :cyan end end |
#pair ⇒ Object
227 228 229 230 231 232 |
# File 'lib/bootic_cli/commands/themes.rb', line 227 def pair within_theme do local_theme = theme_selector.pair(['shop'], current_dir) prompt.say "Directory #{File.dirname(local_theme.path)} paired with shop #{['shop']}", :green end end |
#publish ⇒ Object
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/bootic_cli/commands/themes.rb', line 175 def publish within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir) if remote_theme.public? prompt.say "You don't seem to have a development theme set up, so there's nothing to publish. :)", :red prompt.say "To push your local changes directly to your public theme, either run the `push` or `sync` commands.", :red else # check if there are any differences between the dev and public themes local_theme, public_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, true) diff = BooticCli::Themes::ThemeDiff.new(source: remote_theme, target: public_theme) unless diff.any? unless prompt.yes_or_no?("Your public and development themes seem to be in sync (no differences). Publish anyway?", false) prompt.say "Okeysay. Bye." exit 1 end end # prompt.say("Publishing means all your public theme's templates and assets will be replaced and lost.") if prompt.yes_or_no?("Would you like to make a local copy of your current public theme before publishing?", diff.any?) # default to true if changes exist path = File.join(local_theme.path, "backups", "public-theme-backup-#{Time.now.to_i}") create_backup_from(public_theme, local_theme, path) end workflows.publish(local_theme, remote_theme) end end end |
#pull ⇒ Object
98 99 100 101 102 103 104 |
# File 'lib/bootic_cli/commands/themes.rb', line 98 def pull within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, ['public']) workflows.pull(local_theme, remote_theme, delete: ['delete'] || true) prompt.say "Done! Preview this theme at #{remote_theme.path}", :cyan end end |
#push ⇒ Object
109 110 111 112 113 114 115 116 |
# File 'lib/bootic_cli/commands/themes.rb', line 109 def push within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, ['public']) warn_about_public if remote_theme.public? and ['public'].nil? workflows.push(local_theme, remote_theme, delete: ['delete'] || true) prompt.say "Done! View updated version at #{remote_theme.path}", :cyan end end |
#sync ⇒ Object
120 121 122 123 124 125 126 127 |
# File 'lib/bootic_cli/commands/themes.rb', line 120 def sync within_theme do local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, ['public']) warn_about_public if remote_theme.public? and ['public'].nil? workflows.sync(local_theme, remote_theme) prompt.say "Synced! Preview this theme at #{remote_theme.path}", :cyan end end |
#watch ⇒ Object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/bootic_cli/commands/themes.rb', line 147 def watch within_theme do if ['force'].nil? && has_lockfile? prompt.say("Looks like there's another process already watching this dir.") prompt.say("If this is not the case, please run this command with --force (or -f)") exit end local_theme, remote_theme = theme_selector.select_theme_pair(default_subdomain, current_dir, ['public']) warn_about_public if remote_theme.public? and ['public'].nil? diff = BooticCli::Themes::ThemeDiff.new(source: local_theme, target: remote_theme) if diff.any? # puts diff.summary if prompt.yes_or_no?("There are differences between the remote theme and your local copy. Sync now?", true) workflows.sync(local_theme, remote_theme) prompt.say "Synced!", :cyan end end write_lockfile at_exit { remove_lockfile } workflows.watch(current_dir, remote_theme) end end |